@@ -72,15 +72,6 @@ discard_unnamed <- function(x) {
   }
 }
 
-captureArgInfo <- function(x) {
-  args <- pairlist(parent.frame())
-  .Call(rlang_capturearginfo, NULL, NULL, args, environment())
-}
-captureDots <- function() {
-  args <- pairlist(parent.frame())
-  .Call(rlang_capturedots, NULL, NULL, args, environment())
-}
-
 cat_line <- function(..., .trailing = TRUE, file = "") {
   cat(paste_line(..., .trailing = .trailing), file = file)
 }
@@ -270,3 +261,11 @@ split_lines <- function(x) {
 stop_internal <- function(fn, msg) {
   abort(sprintf("Internal error in `%s()`: %s"), fn, msg)
 }
+
+with_srcref <- function(src, env = caller_env(), file = NULL) {
+  file <- file %||% tempfile("sourced", fileext = ".R")
+  on.exit(unlink(file))
+
+  writeLines(src, file)
+  source(file, local = env, keep.source = TRUE)
+}
