@@ -6,8 +6,7 @@
 
 extern sexp* rlang_zap;
 
-extern sexp* as_list_call;
-extern sexp* as_list_s4_call;
+extern sexp* rlang_as_list_call;
 
 extern sexp* rlang_objs_keep;
 extern sexp* rlang_objs_trailing;
@@ -15,7 +14,7 @@ extern sexp* rlang_objs_trailing;
 extern sexp* fns_function;
 extern sexp* fns_quote;
 
-void rlang_init_internal();
+void rlang_init_internal(sexp* ns);
 sexp* rlang_ns_get(const char* name);
 
 // From dots.c
