@@ -44,6 +44,13 @@ skip_if_stale_backtrace <- local({
   }
 })
 
+skip_if_big_endian <- function() {
+  skip_if(
+    identical(.Platform$endian, "big"),
+    "Skipping on big-endian platform."
+  )
+}
+
 Rscript <- function(args, ...) {
   out <- suppressWarnings(system2(
     file.path(R.home("bin"), "Rscript"),
@@ -58,3 +65,7 @@ Rscript <- function(args, ...) {
     status = attr(out, "status")
   )
 }
+
+expect_reference <- function(object, expected) {
+  expect_true(is_reference(object, expected))
+}
